@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: TopologyException.cpp,v 1.8 2004/07/02 13:28:26 strk Exp $
+ * $Id: TopologyException.cpp,v 1.9 2004/12/13 13:53:03 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,6 +13,9 @@
  *
  **********************************************************************
  * $Log: TopologyException.cpp,v $
+ * Revision 1.9  2004/12/13 13:53:03  strk
+ * Fixed uninitialized Coordinate.
+ *
  * Revision 1.8  2004/07/02 13:28:26  strk
  * Fixed all #include lines to reflect headers layout change.
  * Added client application build tips in README.
@@ -32,10 +35,12 @@
 namespace geos {
 
 TopologyException::TopologyException(string msg): GEOSException("TopologyException", msg) {
+	pt=NULL;
 }
 
 TopologyException::TopologyException(string msg,const Coordinate *newPt): GEOSException("TopologyException", msg+" "+newPt->toString()) {
-	pt=new Coordinate(*newPt);
+	if ( newPt ) pt=new Coordinate(*newPt);
+	else pt=NULL;
 }
 
 TopologyException::~TopologyException() {
