@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: geom.h,v 1.27 2004/09/16 09:48:06 strk Exp $
+ * $Id: geom.h,v 1.35 2004/12/16 16:27:24 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -11,211 +11,6 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
- **********************************************************************
- * $Log: geom.h,v $
- * Revision 1.27  2004/09/16 09:48:06  strk
- * Added Envelope::equals
- *
- * Revision 1.26  2004/09/13 12:39:14  strk
- * Made Point and MultiPoint subject to Validity tests.
- *
- * Revision 1.25  2004/09/07 08:29:57  strk
- * Fixed doxygen malformed comment for Coordinate class
- *
- * Revision 1.24  2004/07/27 16:35:46  strk
- * Geometry::getEnvelopeInternal() changed to return a const Envelope *.
- * This should reduce object copies as once computed the envelope of a
- * geometry remains the same.
- *
- * Revision 1.23  2004/07/26 16:35:19  strk
- * Removed dangling MultiPoint::isClosed() method definition.
- *
- * Revision 1.22  2004/07/22 16:58:01  strk
- * runtime version extractor functions split. geos::version() is now
- * geos::geosversion() and geos::jtsport()
- *
- * Revision 1.21  2004/07/22 08:45:50  strk
- * Documentation updates, memory leaks fixed.
- *
- * Revision 1.20  2004/07/22 07:19:21  strk
- * Changed getCoordinatesRO description.
- *
- * Revision 1.19  2004/07/22 07:04:49  strk
- * Documented missing geometry functions.
- *
- * Revision 1.18  2004/07/21 09:55:24  strk
- * CoordinateSequence::atLeastNCoordinatesOrNothing definition fix.
- * Documentation fixes.
- *
- * Revision 1.17  2004/07/20 08:34:18  strk
- * Fixed a bug in opDistance.h.
- * Removed doxygen tags from obsoleted CoordinateList.cpp.
- * Got doxygen to run with no warnings.
- *
- * Revision 1.16  2004/07/19 13:19:30  strk
- * Documentation fixes
- *
- * Revision 1.15  2004/07/19 10:34:06  strk
- * removed doxygen documentation of removed feature
- *
- * Revision 1.14  2004/07/17 09:18:54  strk
- * Added geos::version()
- *
- * Revision 1.13  2004/07/14 21:17:10  strk
- * added inequality operator for Coordinate
- *
- * Revision 1.12  2004/07/13 08:33:52  strk
- * Added missing virtual destructor to virtual classes.
- * Fixed implicit unsigned int -> int casts
- *
- * Revision 1.11  2004/07/12 19:16:39  strk
- * Commented out CoordinateList class definition.
- *
- * Revision 1.10  2004/07/08 19:34:49  strk
- * Mirrored JTS interface of CoordinateSequence, factory and
- * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
- *
- * Revision 1.9  2004/07/07 09:38:12  strk
- * Dropped WKTWriter::stringOfChars (implemented by std::string).
- * Dropped WKTWriter default constructor (internally created GeometryFactory).
- * Updated XMLTester to respect the changes.
- * Main documentation page made nicer.
- *
- * Revision 1.8  2004/07/06 17:58:22  strk
- * Removed deprecated Geometry constructors based on PrecisionModel and
- * SRID specification. Removed SimpleGeometryPrecisionReducer capability
- * of changing Geometry's factory. Reverted Geometry::factory member
- * to be a reference to external factory.
- *
- * Revision 1.7  2004/07/05 19:40:48  strk
- * Added GeometryFactory::destroyGeometry(Geometry *)
- *
- * Revision 1.6  2004/07/05 15:20:18  strk
- * Documentation again.
- *
- * Revision 1.5  2004/07/05 14:23:03  strk
- * More documentation cleanups.
- *
- * Revision 1.4  2004/07/05 10:50:21  strk
- * deep-dopy construction taken out of Geometry and implemented only
- * in GeometryFactory.
- * Deep-copy geometry construction takes care of cleaning up copies
- * on exception.
- * Implemented clone() method for CoordinateSequence
- * Changed createMultiPoint(CoordinateSequence) signature to reflect
- * copy semantic (by-ref instead of by-pointer).
- * Cleaned up documentation.
- *
- * Revision 1.3  2004/07/03 12:51:37  strk
- * Documentation cleanups for DoxyGen.
- *
- * Revision 1.2  2004/07/02 14:27:32  strk
- * Added deep-copy / take-ownerhship for Point type.
- *
- * Revision 1.1  2004/07/02 13:20:42  strk
- * Header files moved under geos/ dir.
- *
- * Revision 1.68  2004/07/01 14:12:44  strk
- *
- * Geometry constructors come now in two flavors:
- * 	- deep-copy args (pass-by-reference)
- * 	- take-ownership of args (pass-by-pointer)
- * Same functionality is available through GeometryFactory,
- * including buildGeometry().
- *
- * Revision 1.67  2004/06/30 20:59:12  strk
- * Removed GeoemtryFactory copy from geometry constructors.
- * Enforced const-correctness on GeometryFactory arguments.
- *
- * Revision 1.66  2004/06/28 21:11:43  strk
- * Moved getGeometryTypeId() definitions from geom.h to each geometry module.
- * Added holes argument check in Polygon.cpp.
- *
- * Revision 1.65  2004/06/15 20:07:51  strk
- * GeometryCollections constructors make a deep copy of Geometry vector argument.
- *
- * Revision 1.64  2004/05/19 13:18:24  strk
- * made CoordinateSequence::toString() a const member function
- *
- * Revision 1.63  2004/05/17 21:14:47  ybychkov
- * JavaDoc updated
- *
- * Revision 1.62  2004/05/17 21:03:56  ybychkov
- * JavaDoc updated
- *
- * Revision 1.61  2004/05/14 12:14:08  strk
- * const correctness
- *
- * Revision 1.60  2004/05/07 09:05:13  strk
- * Some const correctness added. Fixed bug in GeometryFactory::createMultiPoint
- * to handle NULL CoordinateSequence.
- *
- * Revision 1.59  2004/05/05 10:54:48  strk
- * Removed some private static heap explicit allocation, less cleanup done by
- * the unloader.
- *
- * Revision 1.58  2004/04/20 08:52:01  strk
- * GeometryFactory and Geometry const correctness.
- * Memory leaks removed from SimpleGeometryPrecisionReducer
- * and GeometryFactory.
- *
- * Revision 1.57  2004/04/16 08:35:52  strk
- * Memory leaks fixed and const correctness applied for Point class.
- *
- * Revision 1.56  2004/04/16 07:42:06  strk
- * PrecisionModel::Type made an enum instead of a Type.
- *
- * Revision 1.55  2004/04/15 14:00:30  strk
- * Added new cleanup to Unload::Release
- *
- * Revision 1.54  2004/04/14 13:56:26  strk
- * All geometries returned by {from,to}InternalGeometry calls are
- * now deleted after use (unless NOT new).
- * Some 'commented' throw specifications in geom.h
- *
- * Revision 1.53  2004/04/14 07:29:43  strk
- * Fixed GeometryFactory constructors to copy given PrecisionModel. Added GeometryFactory copy constructor. Fixed Geometry constructors to copy GeometryFactory.
- *
- * Revision 1.52  2004/04/13 08:15:51  strk
- * Changed all 'long long' with int64.
- * Changed all 'long long' constants to end with two Ls.
- *
- * Revision 1.51  2004/04/10 22:41:24  ybychkov
- * "precision" upgraded to JTS 1.4
- *
- * Revision 1.50  2004/04/07 06:55:50  ybychkov
- * "operation/linemerge" ported from JTS 1.4
- *
- * Revision 1.49  2004/04/04 06:29:11  ybychkov
- * "planargraph" and "geom/utill" upgraded to JTS 1.4
- *
- * Revision 1.48  2004/04/01 10:44:34  ybychkov
- * All "geom" classes from JTS 1.3 upgraded to JTS 1.4
- *
- * Revision 1.47  2004/03/31 07:50:37  ybychkov
- * "geom" partially upgraded to JTS 1.4
- *
- * Revision 1.46  2004/03/29 06:59:24  ybychkov
- * "noding/snapround" package ported (JTS 1.4);
- * "operation", "operation/valid", "operation/relate" and "operation/overlay" upgraded to JTS 1.4;
- * "geom" partially upgraded.
- *
- * Revision 1.45  2004/03/18 10:42:44  ybychkov
- * "IO" and "Util" upgraded to JTS 1.4
- * "Geometry" partially upgraded.
- *
- * Revision 1.44  2004/03/17 02:00:33  ybychkov
- * "Algorithm" upgraded to JTS 1.4
- *
- * Revision 1.43  2004/03/01 22:04:59  strk
- * applied const correctness changes by Manuel Prieto Villegas <ManuelPrietoVillegas@telefonica.net>
- *
- * Revision 1.42  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- *
  **********************************************************************/
 
 #ifndef GEOS_GEOM_H
@@ -515,7 +310,11 @@ private:
 	void setScale(double newScale);
 	Type modelType;
 	double scale;
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = 7777263578777803835I64;
+#else        
 	static const int64 serialVersionUID = 7777263578777803835LL;
+#endif        
 };
 
 /**
@@ -622,7 +421,7 @@ public:
 	}
 
 	bool Coordinate::equals3D(const Coordinate& other) const {
-		return (x == other.x) && ( y == other.y) && (( z == other.z)||(z==DoubleNotANumber && other.z==DoubleNotANumber));
+		return (x == other.x) && ( y == other.y) && ((z == other.z)||(ISNAN(z) && ISNAN(other.z)));
 	}
 
 	void Coordinate::makePrecise(const PrecisionModel *precisionModel) {
@@ -662,8 +461,11 @@ public:
 	double z;
 
 private:
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID=6683108902428366910I64;
+#else
 	static const int64 serialVersionUID=6683108902428366910LL;
-
+#endif
 
 };
 
@@ -797,6 +599,9 @@ public:
 	 */
 	void add(const vector<Coordinate>* vc, bool allowRepeated);
 
+	/* This is here for backward compatibility.. */
+	void add(CoordinateSequence *cl,bool allowRepeated,bool direction);
+
 	/**
 	 * \brief Add an array of coordinates 
 	 * @param cl The coordinates
@@ -805,7 +610,7 @@ public:
 	 * @param direction if false, the array is added in reverse order
 	 * @return true (as by general collection contract)
 	 */
-	void add(CoordinateSequence *cl,bool allowRepeated,bool direction);
+	void add(const CoordinateSequence *cl,bool allowRepeated,bool direction);
 
 	/**
 	 * \brief Add a coordinate
@@ -893,9 +698,6 @@ public:
  */
 class DefaultCoordinateSequence : public CoordinateSequence {
 public:
-	//DefaultCoordinateSequence(int n);
-	//DefaultCoordinateSequence(const Coordinate& c);
-	//DefaultCoordinateSequence(const CoordinateSequence *c);
 
 	DefaultCoordinateSequence(const DefaultCoordinateSequence &cl);
 
@@ -906,7 +708,7 @@ public:
 
 	//int size() const;
 	int getSize() const;
-	vector<Coordinate>* toVector() const;
+	const vector<Coordinate>* toVector() const;
 
 	/// Construct an empty sequence
 	DefaultCoordinateSequence();
@@ -953,13 +755,14 @@ public:
 	void setAt(const Coordinate& c, int pos);
 	void setAt(point_3d p, int pos);
 	void deleteAt(int pos);
-	vector<Coordinate>* toVector() const;
+	const vector<Coordinate>* toVector() const;
 	vector<point_3d>* toPointVector();
 	string toString() const;
 	void setPoints(const vector<Coordinate> &v);
 	void setPoints(vector<point_3d> &v);
 private:
 	vector<point_3d> *vect;
+	mutable vector<Coordinate>*cached_vector;
 };
 
 /**
@@ -1038,14 +841,14 @@ public:
 };
 
 /*
- *  <code>Geometry</code> classes support the concept of applying a
- *  coordinate filter to every coordinate in the <code>Geometry</code>. A
- *  coordinate filter can either record information about each coordinate or
- *  change the coordinate in some way. Coordinate filters implement the
- *  interface <code>CoordinateFilter</code>. (<code>CoordinateFilter</code> is
- *  an example of the Gang-of-Four Visitor pattern). Coordinate filters can be
- *  used to implement such things as coordinate transformations, centroid and
- *  envelope computation, and many other functions.
+ * <code>Geometry</code> classes support the concept of applying a
+ * coordinate filter to every coordinate in the <code>Geometry</code>. A
+ * coordinate filter can either record information about each coordinate or
+ * change the coordinate in some way. Coordinate filters implement the
+ * interface <code>CoordinateFilter</code>. (<code>CoordinateFilter</code> is
+ * an example of the Gang-of-Four Visitor pattern). Coordinate filters can be
+ * used to implement such things as coordinate transformations, centroid and
+ * envelope computation, and many other functions.
  *
  */
 class CoordinateFilter {
@@ -1169,14 +972,19 @@ public:
 	bool equals(const Envelope* other) const;
 	string toString(void) const;
 	double distance(const Envelope* env) const;
-    int hashCode() const;
+	int hashCode() const;
+
 private:
 	static double distance(double x0,double y0,double x1,double y1);
 	double minx;	/// the minimum x-coordinate
 	double maxx;	/// the maximum x-coordinate
 	double miny;	/// the minimum y-coordinate
 	double maxy;	/// the maximum y-coordinate
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID=5873921885273102420I64;
+#else        
 	static const int64 serialVersionUID=5873921885273102420LL;
+#endif        
 };
 
 class Geometry;
@@ -1344,7 +1152,7 @@ public:
 	/*
 	 * Sets the ID of the Spatial Reference System used by the
 	 * <code>Geometry</code>.
-	 * @deprecated use {@link setUserData} instead
+	 * @deprecated use setUserData instead
 	 */
 	virtual void setSRID(int newSRID);
 
@@ -1377,14 +1185,14 @@ public:
 	virtual GeometryTypeId getGeometryTypeId() const=0; //Abstract
 
 	/**
-	* \brief Tests the validity of this <code>Geometry</code>.
-	*
-	* Subclasses provide their own definition of "valid".
-	*
-	* @return <code>true</code> if this <code>Geometry</code> is valid
-	*
-	* @see IsValidOp
-	*/
+	 * \brief Tests the validity of this <code>Geometry</code>.
+	 *
+	 * Subclasses provide their own definition of "valid".
+	 *
+	 * @return <code>true</code> if this <code>Geometry</code> is valid
+	 *
+	 * @see IsValidOp
+	 */
 	virtual bool isValid() const;
 
 	/// Returns whether or not the set of points in this Geometry is empty.
@@ -1621,7 +1429,11 @@ protected:
 private:
 	virtual int getClassSortIndex() const;
 	static GeometryComponentFilter geometryChangedFilter;
+#ifdef INT64_CONST_IS_I64
+    static const int64 serialVersionUID = 8763622679187376702I64;
+#else
     static const int64 serialVersionUID = 8763622679187376702LL;
+#endif
 	const GeometryFactory *factory;
 	static const GeometryFactory* INTERNAL_GEOMETRY_FACTORY;
 	void* userData;
@@ -1629,22 +1441,22 @@ private:
 };
 
 /*
- * <code>Geometry</code> classes support the concept of applying a <code>Geometry</code>
- *  filter to the <code>Geometry</code>. In the case of <code>GeometryCollection</code>
- *  subclasses, the filter is applied to every element <code>Geometry</code>. A
- *  <code>Geometry</code> filter can either record information about the <code>Geometry</code>
- *  or change the <code>Geometry</code> in some way. <code>Geometry</code>
- *  filters implement the interface <code>GeometryFilter</code>. (<code>GeometryFilter</code>
- *  is an example of the Gang-of-Four Visitor pattern).
- *
+ * Geometry classes support the concept of applying a Geometry
+ * filter to the Geometry. In the case of GeometryCollection
+ * subclasses, the filter is applied to every element Geometry.
+ * A Geometry filter can either record information about the Geometry
+ * or change the Geometry in some way.
+ * Geometry filters implement the interface GeometryFilter.
+ * (GeometryFilter is an example of the Gang-of-Four Visitor pattern).
  */
 class GeometryFilter {
 public:
-  /**
-   *  Performs an operation with or on <code>geom</code>.
-   *
-   *@param  geom  a <code>Geometry</code> to which the filter is applied.
-   */
+	/*
+	 * Performs an operation with or on <code>geom</code>.
+	 *
+	 * @param  geom  a <code>Geometry</code> to which the filter
+	 *         is applied.
+	 */
 	virtual void filter_ro(const Geometry *geom)=0;
 	virtual void filter_rw(Geometry *geom)=0;
 };
@@ -1747,7 +1559,11 @@ public:
 	Coordinate* intersection(const LineSegment *line) const;
 	virtual string toString() const;
 private:
+#ifdef INT64_CONST_IS_I64
+  static const int64 serialVersionUID=3252005833466256227I64;
+#else
   static const int64 serialVersionUID=3252005833466256227LL;
+#endif
 
 };
 
@@ -1936,7 +1752,11 @@ protected:
 	virtual Envelope* computeEnvelopeInternal() const;
 	virtual int compareToSameClass(const Geometry *gc) const;
 private:
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = -5694727726395021467I64;
+#else
 	static const int64 serialVersionUID = -5694727726395021467LL;
+#endif        
 };
 
 class GeometryCollectionIterator {
@@ -2016,7 +1836,11 @@ private:
 	*  The <code>Coordinate</code> wrapped by this <code>Point</code>.
 	*/
 	CoordinateSequence *coordinates;
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = 4902022702746614570I64;
+#else        
 	static const int64 serialVersionUID = 4902022702746614570LL;
+#endif        
 };
 
 /**
@@ -2087,7 +1911,11 @@ protected:
 	virtual Envelope* computeEnvelopeInternal() const;
 	CoordinateSequence* points;
 private:
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = 3110669828065365560I64;
+#else
 	static const int64 serialVersionUID = 3110669828065365560LL;
+#endif        
 };
 
 /**
@@ -2119,6 +1947,7 @@ public:
 	*/
 	LinearRing(CoordinateSequence* points, const GeometryFactory *newFactory);
 
+	virtual Geometry *clone() const;
 	virtual ~LinearRing();
 	bool isSimple() const;
 	string getGeometryType() const;
@@ -2126,7 +1955,11 @@ public:
 	bool isClosed() const;
 	void setPoints(CoordinateSequence* cl);
 private:
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = -4261142084085851829I64;
+#else
 	static const int64 serialVersionUID = -4261142084085851829LL;
+#endif        
 	void validateConstruction();
 };
 
@@ -2226,7 +2059,11 @@ protected:
 	Envelope* computeEnvelopeInternal() const;
 private:
 	void normalize(LinearRing *ring, bool clockwise);
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = -3494792200821764533I64;
+#else
 	static const int64 serialVersionUID = -3494792200821764533LL;
+#endif        
 };
 
 /**
@@ -2275,7 +2112,11 @@ public:
 protected:
 	const Coordinate* getCoordinate(int n) const;
 private:
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = -8048474874175355449I64;
+#else
 	static const int64 serialVersionUID = -8048474874175355449LL;
+#endif        
 };
 
 /**
@@ -2327,7 +2168,11 @@ public:
 	bool isSimple() const;
 	bool equalsExact(const Geometry *other, double tolerance) const;
 private:
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = 8166665132445433741I64;
+#else
 	static const int64 serialVersionUID = 8166665132445433741LL;
+#endif        
 };
 
 /**
@@ -2381,7 +2226,11 @@ public:
 	bool isSimple() const;
 	bool equalsExact(const Geometry *other, double tolerance) const;
 private:
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = -551033529766975875I64;
+#else
 	static const int64 serialVersionUID = -551033529766975875LL;
+#endif        
 };
 
 /**
@@ -2552,7 +2401,11 @@ public:
 private:
 	const PrecisionModel* precisionModel;
 	int SRID;
+#ifdef INT64_CONST_IS_I64
+	static const int64 serialVersionUID = -6820524753094095635I64;
+#else
 	static const int64 serialVersionUID = -6820524753094095635LL;
+#endif        
 	const CoordinateSequenceFactory *coordinateListFactory;
 };
 
@@ -2573,5 +2426,63 @@ public:
 	*/
 	Coordinate* inCentre();
 };
-}
+
+} // namespace geos
 #endif
+
+/**********************************************************************
+ * $Log: geom.h,v $
+ * Revision 1.35  2004/12/16 16:27:24  strk
+ * Fixed LinearRing::clone() to return LinearRing instead of LineString
+ *
+ * Revision 1.34  2004/12/03 22:52:56  strk
+ * enforced const return of CoordinateSequence::toVector() method to derivate classes.
+ *
+ * Revision 1.33  2004/12/03 16:22:36  frank
+ * update to use I64 on MSVC for 64 bit integer constants, also toVector chg.
+ *
+ * Revision 1.32  2004/11/29 16:05:33  strk
+ * Fixed a bug in LineIntersector::interpolateZ causing NaN values
+ * to come out.
+ * Handled dimensional collapses in ElevationMatrix.
+ * Added ISNAN macro and changed ISNAN/FINITE macros to avoid
+ * dispendious isnan() and finite() calls.
+ *
+ * Revision 1.31  2004/11/23 16:22:49  strk
+ * Added ElevationMatrix class and components to do post-processing draping of overlayed geometries.
+ *
+ * Revision 1.30  2004/11/17 08:13:16  strk
+ * Indentation changes.
+ * Some Z_COMPUTATION activated by default.
+ *
+ * Revision 1.29  2004/11/08 10:57:42  strk
+ * Moved Log lines at the bottom, and cut oldest
+ *
+ * Revision 1.28  2004/10/13 10:03:02  strk
+ * Added missing linemerge and polygonize operation.
+ * Bug fixes and leaks removal from the newly added modules and
+ * planargraph (used by them).
+ * Some comments and indentation changes.
+ *
+ * Revision 1.27  2004/09/16 09:48:06  strk
+ * Added Envelope::equals
+ *
+ * Revision 1.26  2004/09/13 12:39:14  strk
+ * Made Point and MultiPoint subject to Validity tests.
+ *
+ * Revision 1.25  2004/09/07 08:29:57  strk
+ * Fixed doxygen malformed comment for Coordinate class
+ *
+ * Revision 1.24  2004/07/27 16:35:46  strk
+ * Geometry::getEnvelopeInternal() changed to return a const Envelope *.
+ * This should reduce object copies as once computed the envelope of a
+ * geometry remains the same.
+ *
+ * Revision 1.23  2004/07/26 16:35:19  strk
+ * Removed dangling MultiPoint::isClosed() method definition.
+ *
+ * Revision 1.22  2004/07/22 16:58:01  strk
+ * runtime version extractor functions split. geos::version() is now
+ * geos::geosversion() and geos::jtsport()
+ *
+ **********************************************************************/
