@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: geomgraph.h,v 1.4 2004/07/19 13:19:31 strk Exp $
+ * $Id: geomgraph.h,v 1.7 2004/11/20 15:46:45 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -11,59 +11,9 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
- **********************************************************************
- * $Log: geomgraph.h,v $
- * Revision 1.4  2004/07/19 13:19:31  strk
- * Documentation fixes
- *
- * Revision 1.3  2004/07/13 08:33:52  strk
- * Added missing virtual destructor to virtual classes.
- * Fixed implicit unsigned int -> int casts
- *
- * Revision 1.2  2004/07/08 19:34:49  strk
- * Mirrored JTS interface of CoordinateSequence, factory and
- * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
- *
- * Revision 1.1  2004/07/02 13:20:42  strk
- * Header files moved under geos/ dir.
- *
- * Revision 1.6  2004/06/30 20:59:12  strk
- * Removed GeoemtryFactory copy from geometry constructors.
- * Enforced const-correctness on GeometryFactory arguments.
- *
- * Revision 1.5  2004/05/26 09:50:05  strk
- * Added comments about OverlayNodeFactory() ownership in NodeMap and PlanarGraph constuctors
- *
- * Revision 1.4  2004/05/03 10:43:42  strk
- * Exception specification considered harmful - left as comment.
- *
- * Revision 1.3  2004/04/10 08:40:01  ybychkov
- * "operation/buffer" upgraded to JTS 1.4
- *
- * Revision 1.2  2004/04/04 06:29:11  ybychkov
- * "planargraph" and "geom/utill" upgraded to JTS 1.4
- *
- * Revision 1.1  2004/03/19 09:48:45  ybychkov
- * "geomgraph" and "geomgraph/indexl" upgraded to JTS 1.4
- *
- * Revision 1.27  2003/11/12 18:02:56  strk
- * Added throw specification. Fixed leaks on exceptions.
- *
- * Revision 1.26  2003/11/12 15:43:38  strk
- * Added some more throw specifications
- *
- * Revision 1.25  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- * Revision 1.24  2003/11/06 18:45:05  strk
- * Added throw specification for DirectEdgeStar::linkResultDirectedEdges()
- *
  **********************************************************************/
 
 
-
 #ifndef GEOS_GEOMGRAPH_H
 #define GEOS_GEOMGRAPH_H
 
@@ -419,6 +369,7 @@ private:
 };
 
 class Node: public GraphComponent {
+
 public:
 	Node(Coordinate& newCoord, EdgeEndStar* newEdges);
 	virtual ~Node();
@@ -432,10 +383,18 @@ public:
 	virtual void setLabelBoundary(int argIndex);
 	virtual int computeMergedLocation(const Label* label2, int eltIndex);
 	virtual string print();
+	virtual const vector<double> &getZ() const;
+	virtual void addZ(double);
+
 protected:
 	Coordinate coord;
 	EdgeEndStar* edges;
 	virtual void computeIM(IntersectionMatrix *im) {};
+
+private:
+	vector<double>zvals;
+	double ztot;
+
 };
 
 class NodeFactory {
@@ -666,9 +625,6 @@ public:
 	GeometryGraph();
 	virtual ~GeometryGraph();
 	GeometryGraph(int newArgIndex, const Geometry *newParentGeom);
-//	GeometryGraph(int newArgIndex, const PrecisionModel *newPrecisionModel, int newSRID);
-//	const PrecisionModel* getPrecisionModel();
-//	int getSRID();
 	const Geometry* getGeometry();
 	vector<Node*>* getBoundaryNodes();
 	CoordinateSequence* getBoundaryPoints();
@@ -676,40 +632,55 @@ public:
 	void computeSplitEdges(vector<Edge*> *edgelist);
 	void addEdge(Edge *e);
 	void addPoint(Coordinate& pt);
-	SegmentIntersector* computeSelfNodes(LineIntersector *li, bool computeRingSelfNodes);
-	SegmentIntersector* computeEdgeIntersections(GeometryGraph *g,LineIntersector *li,bool includeProper);
+	SegmentIntersector* computeSelfNodes(LineIntersector *li,
+		bool computeRingSelfNodes);
+	SegmentIntersector* computeEdgeIntersections(GeometryGraph *g,
+		LineIntersector *li,bool includeProper);
 	vector<Edge*> *getEdges();
 	bool hasTooFewPoints();
 	const Coordinate& getInvalidPoint(); 
+
 private:
+
 	const Geometry *parentGeom;
-	// the precision model of the Geometry represented by this graph
-//	const PrecisionModel *precisionModel;
-//	int SRID;
-	/**
-	* The lineEdgeMap is a map of the linestring components of the
-	* parentGeometry to the edges which are derived from them.
-	* This is used to efficiently perform findEdge queries
-	*/
+
+	/*
+	 * The lineEdgeMap is a map of the linestring components of the
+	 * parentGeometry to the edges which are derived from them.
+	 * This is used to efficiently perform findEdge queries
+	 */
 	map<const LineString*,Edge*,LineStringLT>* lineEdgeMap;
-	/**
-	* If this flag is true, the Boundary Determination Rule will used when deciding
-	* whether nodes are in the boundary or not
-	*/
+
+	/*
+	 * If this flag is true, the Boundary Determination Rule will
+	 * used when deciding whether nodes are in the boundary or not
+	 */
 	bool useBoundaryDeterminationRule;
-	int argIndex;  // the index of this geometry as an argument to a spatial function (used for labelling)
+
+	/*
+	 * the index of this geometry as an argument to a spatial function
+	 * (used for labelling)
+	 */
+	int argIndex;
+
 	vector<Node*>* boundaryNodes;
+
 	bool hasTooFewPointsVar;
+
 	Coordinate invalidPoint; 
+
 	EdgeSetIntersector* createEdgeSetIntersector();
+
 	void add(const Geometry *g); // throw(UnsupportedOperationException *);
 	void addCollection(const GeometryCollection *gc);
 	void addPoint(const Point *p);
 	void addPolygonRing(const LinearRing *lr,int cwLeft,int cwRight);
 	void addPolygon(const Polygon *p);
 	void addLineString(const LineString *line);
+
 	void insertPoint(int argIndex, const Coordinate& coord,int onLocation);
 	void insertBoundaryPoint(int argIndex, const Coordinate& coord);
+
 	void addSelfIntersectionNodes(int argIndex);
 	void addSelfIntersectionNode(int argIndex,Coordinate& coord,int loc);
 };
@@ -735,5 +706,69 @@ public:
 
 //Operators
 bool operator==(Edge a,Edge b);
-}
-#endif
+
+} // namespace geos
+
+#endif // ifndef GEOS_GEOMGRAPH_H
+
+/**********************************************************************
+ * $Log: geomgraph.h,v $
+ * Revision 1.7  2004/11/20 15:46:45  strk
+ * Added composing Z management functions and elements for class Node
+ *
+ * Revision 1.6  2004/11/17 08:13:16  strk
+ * Indentation changes.
+ * Some Z_COMPUTATION activated by default.
+ *
+ * Revision 1.5  2004/10/21 22:29:54  strk
+ * Indentation changes and some more COMPUTE_Z rules
+ *
+ * Revision 1.4  2004/07/19 13:19:31  strk
+ * Documentation fixes
+ *
+ * Revision 1.3  2004/07/13 08:33:52  strk
+ * Added missing virtual destructor to virtual classes.
+ * Fixed implicit unsigned int -> int casts
+ *
+ * Revision 1.2  2004/07/08 19:34:49  strk
+ * Mirrored JTS interface of CoordinateSequence, factory and
+ * default implementations.
+ * Added DefaultCoordinateSequenceFactory::instance() function.
+ *
+ * Revision 1.1  2004/07/02 13:20:42  strk
+ * Header files moved under geos/ dir.
+ *
+ * Revision 1.6  2004/06/30 20:59:12  strk
+ * Removed GeoemtryFactory copy from geometry constructors.
+ * Enforced const-correctness on GeometryFactory arguments.
+ *
+ * Revision 1.5  2004/05/26 09:50:05  strk
+ * Added comments about OverlayNodeFactory() ownership in NodeMap and PlanarGraph constuctors
+ *
+ * Revision 1.4  2004/05/03 10:43:42  strk
+ * Exception specification considered harmful - left as comment.
+ *
+ * Revision 1.3  2004/04/10 08:40:01  ybychkov
+ * "operation/buffer" upgraded to JTS 1.4
+ *
+ * Revision 1.2  2004/04/04 06:29:11  ybychkov
+ * "planargraph" and "geom/utill" upgraded to JTS 1.4
+ *
+ * Revision 1.1  2004/03/19 09:48:45  ybychkov
+ * "geomgraph" and "geomgraph/indexl" upgraded to JTS 1.4
+ *
+ * Revision 1.27  2003/11/12 18:02:56  strk
+ * Added throw specification. Fixed leaks on exceptions.
+ *
+ * Revision 1.26  2003/11/12 15:43:38  strk
+ * Added some more throw specifications
+ *
+ * Revision 1.25  2003/11/07 01:23:42  pramsey
+ * Add standard CVS headers licence notices and copyrights to all cpp and h
+ * files.
+ *
+ * Revision 1.24  2003/11/06 18:45:05  strk
+ * Added throw specification for DirectEdgeStar::linkResultDirectedEdges()
+ *
+ **********************************************************************/
+
