@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: geosAlgorithm.h,v 1.6 2004/09/13 10:12:49 strk Exp $
+ * $Id: geosAlgorithm.h,v 1.9 2004/11/23 19:53:07 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,6 +13,16 @@
  *
  **********************************************************************
  * $Log: geosAlgorithm.h,v $
+ * Revision 1.9  2004/11/23 19:53:07  strk
+ * Had LineIntersector compute Z by interpolation.
+ *
+ * Revision 1.8  2004/11/06 08:16:46  strk
+ * Fixed CGAlgorithms::isCCW from JTS port.
+ * Code cleanup in IsValidOp.
+ *
+ * Revision 1.7  2004/10/21 22:29:54  strk
+ * Indentation changes and some more COMPUTE_Z rules
+ *
  * Revision 1.6  2004/09/13 10:12:49  strk
  * Added invalid coordinates checks in IsValidOp.
  * Cleanups.
@@ -132,17 +142,22 @@ public:
 	* segment in the linestring
 	*/
 	static bool isOnLine(const Coordinate& p, const CoordinateSequence* pt);
-	/**
-	* Computes whether a ring defined by an array of {@link Coordinate} is
-	* oriented counter-clockwise.
-	* <p>
-	* This will handle coordinate lists which contain repeated points.
-	*
-	* @param ring an array of coordinates forming a ring
-	* @return <code>true</code> if the ring is oriented counter-clockwise.
-	* @throws IllegalArgumentException if the ring is degenerate (does not contain 3 distinct points)
-	*/
+
+	/*
+	 * Computes whether a ring defined by an array of Coordinate is
+	 * oriented counter-clockwise.
+	 * 
+	 *  - The list of points is assumed to have the first and last
+	 *    points equal.
+	 *  - This will handle coordinate lists which contain repeated points.
+	 *  - If the ring is invalid, the answer returned may not be correct.
+	 * 
+	 *
+	 * @param ring an array of coordinates forming a ring
+	 * @return <code>true</code> if the ring is oriented counter-clockwise.
+	 */
 	static bool isCCW(const CoordinateSequence* ring);
+
 	/**
 	* Computes the orientation of a point q to the directed line segment p1-p2.
 	* The orientation of a point relative to a directed line segment indicates
@@ -215,42 +230,62 @@ private:
 
 class LineIntersector{
 public:	
+	// Return a Z value being the interpolation of Z from p0 and p1 at
+	// the given point p
+	static double interpolateZ(const Coordinate &p, const Coordinate &p0, const Coordinate &p1);
 	static double computeEdgeDistance(const Coordinate& p, const Coordinate& p0, const Coordinate& p1);
 	static double nonRobustComputeEdgeDistance(const Coordinate& p,const Coordinate& p1,const Coordinate& p2);
 	LineIntersector();
 	virtual ~LineIntersector();
-	/**
-	* Tests whether either intersection point is an interior point of one of the input segments.
-	*
-	* @return <code>true</code> if either intersection point is in the interior of one of the input segments
-	*/
+
+	/*
+	 * Tests whether either intersection point is an interior point of
+	 * one of the input segments.
+	 *
+	 * @return <code>true</code> if either intersection point is in
+	 * the interior of one of the input segments
+	 */
 	virtual bool isInteriorIntersection();
-	/**
-	* Tests whether either intersection point is an interior point of the specified input segment.
-	*
-	* @return <code>true</code> if either intersection point is in the interior of the input segment
-	*/
+
+	/*
+	 * Tests whether either intersection point is an interior point
+	 * of the specified input segment.
+	 *
+	 * @return <code>true</code> if either intersection point is in
+	 * the interior of the input segment
+	 */
 	virtual bool isInteriorIntersection(int inputLineIndex);
+
 	virtual void setMakePrecise(const PrecisionModel *newPM);
+
 	virtual void setPrecisionModel(const PrecisionModel *newPM);
-	/**
-	* Compute the intersection of a point p and the line p1-p2.
-	* This function computes the boolean value of the hasIntersection test.
-	* The actual value of the intersection (if there is one)
-	* is equal to the value of <code>p</code>.
-	*/
-	virtual void computeIntersection(const Coordinate& p,const Coordinate& p1,const Coordinate& p2) =0;
+
+	/*
+	 * Compute the intersection of a point p and the line p1-p2.
+	 * This function computes the boolean value of the hasIntersection test.
+	 * The actual value of the intersection (if there is one)
+	 * is equal to the value of <code>p</code>.
+	 */
+	virtual void computeIntersection(const Coordinate& p,const Coordinate& p1,const Coordinate& p2)=0;
+
 	enum {
 		DONT_INTERSECT,
 		DO_INTERSECT,
 		COLLINEAR
 	};
+
 	virtual void computeIntersection(const Coordinate& p1,const Coordinate& p2,const Coordinate& p3, const Coordinate& p4);
+
 	virtual string toString() const;
+
 	virtual bool hasIntersection() const;
+
 	virtual int getIntersectionNum() const;
+
 	virtual const Coordinate& getIntersection(int intIndex) const;
+
 	static bool isSameSignAndNonZero(double a,double b);
+
 	virtual bool isIntersection(const Coordinate& pt) const;
 	virtual bool isProper() const;
 	virtual const Coordinate& getIntersectionAlongSegment(int segmentIndex,int intIndex);
