@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: opBuffer.h,v 1.3 2004/07/19 13:19:31 strk Exp $
+ * $Id: opBuffer.h,v 1.6 2004/12/08 13:54:43 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -11,90 +11,8 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
- **********************************************************************
- * $Log: opBuffer.h,v $
- * Revision 1.3  2004/07/19 13:19:31  strk
- * Documentation fixes
- *
- * Revision 1.2  2004/07/08 19:34:49  strk
- * Mirrored JTS interface of CoordinateSequence, factory and
- * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
- *
- * Revision 1.1  2004/07/02 13:20:42  strk
- * Header files moved under geos/ dir.
- *
- * Revision 1.22  2004/07/01 14:12:44  strk
- *
- * Geometry constructors come now in two flavors:
- * 	- deep-copy args (pass-by-reference)
- * 	- take-ownership of args (pass-by-pointer)
- * Same functionality is available through GeometryFactory,
- * including buildGeometry().
- *
- * Revision 1.21  2004/06/30 20:59:13  strk
- * Removed GeoemtryFactory copy from geometry constructors.
- * Enforced const-correctness on GeometryFactory arguments.
- *
- * Revision 1.20  2004/05/27 08:37:16  strk
- * Fixed a bug preventing OffsetCurveBuilder point list from being reset.
- *
- * Revision 1.19  2004/05/26 09:49:03  strk
- * PlanarGraph made local to ::buffer instead of Class private.
- *
- * Revision 1.18  2004/05/07 07:57:27  strk
- * Added missing EdgeNodingValidator to build scripts.
- * Changed SegmentString constructor back to its original form
- * (takes const void *), implemented local tracking of "contexts"
- * in caller objects for proper destruction.
- *
- * Revision 1.17  2004/05/05 16:57:48  strk
- * Rewritten static cga allocation to avoid copy constructor calls.
- *
- * Revision 1.16  2004/05/05 10:54:48  strk
- * Removed some private static heap explicit allocation, less cleanup done by
- * the unloader.
- *
- * Revision 1.15  2004/05/03 10:43:42  strk
- * Exception specification considered harmful - left as comment.
- *
- * Revision 1.14  2004/04/30 09:15:28  strk
- * Enlarged exception specifications to allow for AssertionFailedException.
- * Added missing initializers.
- *
- * Revision 1.13  2004/04/23 00:02:18  strk
- * const-correctness changes
- *
- * Revision 1.12  2004/04/20 10:58:04  strk
- * More memory leaks removed.
- *
- * Revision 1.11  2004/04/19 15:14:45  strk
- * Added missing virtual destructor in SpatialIndex class.
- * Memory leaks fixes. Const and throw specifications added.
- *
- * Revision 1.10  2004/04/19 12:51:01  strk
- * Memory leaks fixes. Throw specifications added.
- *
- * Revision 1.9  2004/04/15 14:00:30  strk
- * Added new cleanup to Unload::Release
- *
- * Revision 1.8  2004/04/10 08:40:01  ybychkov
- * "operation/buffer" upgraded to JTS 1.4
- *
- * Revision 1.7  2004/03/01 22:04:59  strk
- * applied const correctness changes by Manuel Prieto Villegas <ManuelPrietoVillegas@telefonica.net>
- *
- * Revision 1.6  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- * Revision 1.5  2003/11/06 18:46:34  strk
- * Added throw specification for BufferOp's ::buildSubgraphs() 
- * and ::computeBuffer()
- *
  **********************************************************************/
 
-
 #ifndef GEOS_OPBUFFER_H
 #define GEOS_OPBUFFER_H
 
@@ -129,11 +47,14 @@ private:
 	void checkForRightmostCoordinate(DirectedEdge *de);
 	int getRightmostSide(DirectedEdge *de, int index);
 	int getRightmostSideOfSegment(DirectedEdge *de, int i);
-	/*
-	* A RightmostEdgeFinder finds the DirectedEdge with the rightmost coordinate.
-	* The DirectedEdge returned is guranteed to have the R of the world on its RHS.
-	*/
+
 public:
+	/*
+	 * A RightmostEdgeFinder finds the DirectedEdge with the
+	 * rightmost coordinate.
+	 * The DirectedEdge returned is guranteed to have the R of
+	 * the world on its RHS.
+	 */
 	RightmostEdgeFinder(CGAlgorithms *newCga);
 	DirectedEdge* getEdge();
 	Coordinate& getCoordinate();
@@ -152,69 +73,88 @@ public:
 class BufferSubgraph {
 private:
 	RightmostEdgeFinder *finder;
+
 	vector<DirectedEdge*> *dirEdgeList;
+
 	vector<Node*> *nodes;
+
 	Coordinate *rightMostCoord;
+
 	/*
-	* Adds all nodes and edges reachable from this node to the subgraph.
-	* Uses an explicit stack to avoid a large depth of recursion.
-	*
-	* @param node a node known to be in the subgraph
-	*/
+	 * Adds all nodes and edges reachable from this node to the subgraph.
+	 * Uses an explicit stack to avoid a large depth of recursion.
+	 *
+	 * @param node a node known to be in the subgraph
+	 */
 	void addReachable(Node *startNode);
+
 	/*
-	* Adds the argument node and all its out edges to the subgraph
-	* @param node the node to add
-	* @param nodeStack the current set of nodes being traversed
-	*/
+	 * Adds the argument node and all its out edges to the subgraph
+	 * @param node the node to add
+	 * @param nodeStack the current set of nodes being traversed
+	 */
 	void add(Node *node,vector<Node*> *nodeStack);
+
 	void clearVisitedEdges();
+
 	/*
-	* Compute depths for all dirEdges via breadth-first traversal of nodes in graph
-	* @param startEdge edge to start processing with
-	*/
+	 * Compute depths for all dirEdges via breadth-first traversal
+	 * of nodes in graph
+	 * @param startEdge edge to start processing with
+	 */
 	// <FIX> MD - use iteration & queue rather than recursion, for speed and robustness
 	void computeDepths(DirectedEdge *startEdge);
+
 	void computeNodeDepth(Node *n);
 	void copySymDepths(DirectedEdge *de);
 	bool contains(vector<Node*> *nodes,Node *node);
+
 public:
 	BufferSubgraph(CGAlgorithms *cga);
 	~BufferSubgraph();
 	vector<DirectedEdge*>* getDirectedEdges();
 	vector<Node*>* getNodes();
+
 	/*
-	* Gets the rightmost coordinate in the edges of the subgraph
-	*/
+	 * Gets the rightmost coordinate in the edges of the subgraph
+	 */
 	Coordinate* getRightmostCoordinate();
+
 	/*
-	* Creates the subgraph consisting of all edges reachable from this node.
-	* Finds the edges in the graph and the rightmost coordinate.
-	*
-	* @param node a node to start the graph traversal from
-	*/
+	 * Creates the subgraph consisting of all edges reachable from
+	 * this node.
+	 * Finds the edges in the graph and the rightmost coordinate.
+	 *
+	 * @param node a node to start the graph traversal from
+	 */
 	void create(Node *node);
+
 	void computeDepth(int outsideDepth);
 	/*
-	* Find all edges whose depths indicates that they are in the result area(s).
-	* Since we want polygon shells to be
-	* oriented CW, choose dirEdges with the interior of the result on the RHS.
-	* Mark them as being in the result.
-	* Interior Area edges are the result of dimensional collapses.
-	* They do not form part of the result area boundary.
-	*/
+	 * Find all edges whose depths indicates that they are in the
+	 * result area(s).
+	 * Since we want polygon shells to be
+	 * oriented CW, choose dirEdges with the interior of the result
+	 * on the RHS.
+	 * Mark them as being in the result.
+	 * Interior Area edges are the result of dimensional collapses.
+	 * They do not form part of the result area boundary.
+	 */
 	void findResultEdges();
+
 	/*
-	* BufferSubgraphs are compared on the x-value of their rightmost Coordinate.
-	* This defines a partial ordering on the graphs such that:
-	* <p>
-	* g1 >= g2 <==> Ring(g2) does not contain Ring(g1)
-	* <p>
-	* where Polygon(g) is the buffer polygon that is built from g.
-	* <p>
-	* This relationship is used to sort the BufferSubgraphs so that shells are guaranteed to
-	* be built before holes.
-	*/
+	 * BufferSubgraphs are compared on the x-value of their rightmost
+	 * Coordinate.
+	 * This defines a partial ordering on the graphs such that:
+	 * 
+	 * g1 >= g2 <==> Ring(g2) does not contain Ring(g1)
+	 *
+	 * where Polygon(g) is the buffer polygon that is built from g.
+	 *
+	 * This relationship is used to sort the BufferSubgraphs so
+	 * that shells are guaranteed to
+	 * be built before holes.
+	 */
 	int compareTo(void* o);
 };
 
@@ -388,12 +328,12 @@ public:
 class OffsetCurveBuilder {
 public:
 	/** \brief
-	* The default number of facets into which to divide a fillet
-	* of 90 degrees.
-	*
-	* A value of 8 gives less than 2% max error in the buffer distance.
-	* For a max error of < 1%, use QS = 12
-	*/
+	 * The default number of facets into which to divide a fillet
+	 * of 90 degrees.
+	 *
+	 * A value of 8 gives less than 2% max error in the buffer distance.
+	 * For a max error of < 1%, use QS = 12
+	 */
 	static const int DEFAULT_QUADRANT_SEGMENTS=8;
 
 	OffsetCurveBuilder(const PrecisionModel *newPrecisionModel);
@@ -402,20 +342,20 @@ public:
 	void setEndCapStyle(int newEndCapStyle);
 
 	/**
-	* This method handles single points as well as lines.
-	* Lines are assumed to <b>not</b> be closed (the function will not
-	* fail for closed lines, but will generate superfluous line caps).
-	*
-	* @return a List of Coordinate[]
-	*/
+	 * This method handles single points as well as lines.
+	 * Lines are assumed to <b>not</b> be closed (the function will not
+	 * fail for closed lines, but will generate superfluous line caps).
+	 *
+	 * @return a List of Coordinate[]
+	 */
 	vector<CoordinateSequence*>* getLineCurve(const CoordinateSequence *inputPts, double distance);
 
 	/**
-	* This method handles the degenerate cases of single points and lines,
-	* as well as rings.
-	*
-	* @return a List of Coordinate[]
-	*/
+	 * This method handles the degenerate cases of single points and lines,
+	 * as well as rings.
+	 *
+	 * @return a List of Coordinate[]
+	 */
 	vector<CoordinateSequence*>* getRingCurve(const CoordinateSequence *inputPts, int side, double distance);
 
 private:
@@ -425,16 +365,21 @@ private:
 //	static final Coordinate[] arrayTypeCoordinate = new Coordinate[0];
 	CGAlgorithms *cga;
 	LineIntersector *li;
+
 	/**
-	* The angle quantum with which to approximate a fillet curve
-	* (based on the input # of quadrant segments)
-	*/
+	 * The angle quantum with which to approximate a fillet curve
+	 * (based on the input # of quadrant segments)
+	 */
 	double filletAngleQuantum;
+
 	/**
-	* the max error of approximation between a quad segment and the true fillet curve
-	*/
+	 * the max error of approximation between a quad segment and
+	 * the true fillet curve
+	 */
 	double maxCurveSegmentError;
+
 	CoordinateSequence *ptList;
+
 	double distance;
 	const PrecisionModel *precisionModel;
 	int endCapStyle;
@@ -561,15 +506,17 @@ private:
 	*/
 	void addPolygonRing(const CoordinateSequence *coord, double offsetDistance, int side, int cwLeftLoc, int cwRightLoc);
 	/**
-	* The ringCoord is assumed to contain no repeated points.
-	* It may be degenerate (i.e. contain only 1, 2, or 3 points).
-	* In this case it has no area, and hence has a minimum diameter of 0.
-	*
-	* @param ringCoord
-	* @param offsetDistance
-	* @return
-	*/
+	 * The ringCoord is assumed to contain no repeated points.
+	 * It may be degenerate (i.e. contain only 1, 2, or 3 points).
+	 * In this case it has no area, and hence has a minimum diameter of 0.
+	 *
+	 * @param ringCoord
+	 * @param offsetDistance
+	 * @return
+	 */
 	bool isErodedCompletely(CoordinateSequence *ringCoord, double bufferDistance);
+	//bool isErodedCompletely(CoordinateSequence *ringCoord, double bufferDistance) { return isErodedCompletely((const CoordinateSequence)ringCoord, bufferDistance) }
+
 	/**
 	* Tests whether a triangular ring would be eroded completely by the given
 	* buffer distance.
@@ -587,7 +534,7 @@ private:
 	* @param bufferDistance
 	* @return
 	*/
-	bool isTriangleErodedCompletely(CoordinateSequence *triangleCoord,double bufferDistance);
+	bool isTriangleErodedCompletely(CoordinateSequence *triangleCoord, double bufferDistance);
 };
 
 /*
@@ -704,31 +651,40 @@ class BufferBuilder {
 friend class Unload;
 public:
 	/**
-	* Creates a new BufferBuilder
-	*/
+	 * Creates a new BufferBuilder
+	 */
 	BufferBuilder();
 	~BufferBuilder();
+
 	/**
-	* Sets the number of segments used to approximate a angle fillet
-	*
-	* @param quadrantSegments the number of segments in a fillet for a quadrant
-	*/
+	 * Sets the number of segments used to approximate a angle fillet
+	 *
+	 * @param quadrantSegments the number of segments in a fillet for
+	 *  a quadrant
+	 */
 	void setQuadrantSegments(int nQuadrantSegments);
+
 	/**
-	* Sets the precision model to use during the curve computation and noding,
-	* if it is different to the precision model of the Geometry.
-	* If the precision model is less than the precision of the Geometry precision model,
-	* the Geometry must have previously been rounded to that precision.
-	*
-	* @param pm the precision model to use
-	*/
+	 * Sets the precision model to use during the curve computation
+	 * and noding,
+	 * if it is different to the precision model of the Geometry.
+	 * If the precision model is less than the precision of the
+	 * Geometry precision model,
+	 * the Geometry must have previously been rounded to that precision.
+	 *
+	 * @param pm the precision model to use
+	 */
 	void setWorkingPrecisionModel(PrecisionModel *pm);
+
 	void setEndCapStyle(int nEndCapStyle);
-	Geometry* buffer(Geometry *g, double distance); // throw (GEOSException *);
+
+	Geometry* buffer(Geometry *g, double distance);
+		// throw (GEOSException *);
+
 private:
 	/**
-	* Compute the change in depth as an edge is crossed from R to L
-	*/
+	 * Compute the change in depth as an edge is crossed from R to L
+	 */
 	static int depthDelta(Label *label);
 	static CGAlgorithms *cga;
 	int quadrantSegments;
@@ -738,23 +694,124 @@ private:
 	EdgeList *edgeList;
 	vector<Label *>newLabels;
 	void computeNodedEdges(vector<SegmentString*> *bufferSegStrList, const PrecisionModel *precisionModel); // throw(GEOSException *);
+
 	/**
-	* Inserted edges are checked to see if an identical edge already exists.
-	* If so, the edge is not inserted, but its label is merged
-	* with the existing edge.
-	*/
+	 * Inserted edges are checked to see if an identical edge already
+	 * exists.
+	 * If so, the edge is not inserted, but its label is merged
+	 * with the existing edge.
+	 */
 	void insertEdge(Edge *e);
 	vector<BufferSubgraph*>* createSubgraphs(PlanarGraph *graph);
+
 	/**
-	* Completes the building of the input subgraphs by depth-labelling them,
-	* and adds them to the PolygonBuilder.
-	* The subgraph list must be sorted in rightmost-coordinate order.
-	*
-	* @param subgraphList the subgraphs to build
-	* @param polyBuilder the PolygonBuilder which will build the final polygons
-	*/
+	 * Completes the building of the input subgraphs by
+	 * depth-labelling them,
+	 * and adds them to the PolygonBuilder.
+	 * The subgraph list must be sorted in rightmost-coordinate order.
+	 *
+	 * @param subgraphList the subgraphs to build
+	 * @param polyBuilder the PolygonBuilder which will build
+	 *        the final polygons
+	 */
 	void buildSubgraphs(vector<BufferSubgraph*> *subgraphList, PolygonBuilder *polyBuilder);
 };
 
-}
-#endif
+} // namespace geos
+
+#endif // ndef GEOS_OPBUFFER_H
+
+/**********************************************************************
+ * $Log: opBuffer.h,v $
+ * Revision 1.6  2004/12/08 13:54:43  strk
+ * gcc warnings checked and fixed, general cleanups.
+ *
+ * Revision 1.5  2004/11/04 19:08:07  strk
+ * Cleanups, initializers list, profiling.
+ *
+ * Revision 1.4  2004/11/01 16:43:04  strk
+ * Added Profiler code.
+ * Temporarly patched a bug in DoubleBits (must check drawbacks).
+ * Various cleanups and speedups.
+ *
+ * Revision 1.3  2004/07/19 13:19:31  strk
+ * Documentation fixes
+ *
+ * Revision 1.2  2004/07/08 19:34:49  strk
+ * Mirrored JTS interface of CoordinateSequence, factory and
+ * default implementations.
+ * Added DefaultCoordinateSequenceFactory::instance() function.
+ *
+ * Revision 1.1  2004/07/02 13:20:42  strk
+ * Header files moved under geos/ dir.
+ *
+ * Revision 1.22  2004/07/01 14:12:44  strk
+ *
+ * Geometry constructors come now in two flavors:
+ * 	- deep-copy args (pass-by-reference)
+ * 	- take-ownership of args (pass-by-pointer)
+ * Same functionality is available through GeometryFactory,
+ * including buildGeometry().
+ *
+ * Revision 1.21  2004/06/30 20:59:13  strk
+ * Removed GeoemtryFactory copy from geometry constructors.
+ * Enforced const-correctness on GeometryFactory arguments.
+ *
+ * Revision 1.20  2004/05/27 08:37:16  strk
+ * Fixed a bug preventing OffsetCurveBuilder point list from being reset.
+ *
+ * Revision 1.19  2004/05/26 09:49:03  strk
+ * PlanarGraph made local to ::buffer instead of Class private.
+ *
+ * Revision 1.18  2004/05/07 07:57:27  strk
+ * Added missing EdgeNodingValidator to build scripts.
+ * Changed SegmentString constructor back to its original form
+ * (takes const void *), implemented local tracking of "contexts"
+ * in caller objects for proper destruction.
+ *
+ * Revision 1.17  2004/05/05 16:57:48  strk
+ * Rewritten static cga allocation to avoid copy constructor calls.
+ *
+ * Revision 1.16  2004/05/05 10:54:48  strk
+ * Removed some private static heap explicit allocation, less cleanup done by
+ * the unloader.
+ *
+ * Revision 1.15  2004/05/03 10:43:42  strk
+ * Exception specification considered harmful - left as comment.
+ *
+ * Revision 1.14  2004/04/30 09:15:28  strk
+ * Enlarged exception specifications to allow for AssertionFailedException.
+ * Added missing initializers.
+ *
+ * Revision 1.13  2004/04/23 00:02:18  strk
+ * const-correctness changes
+ *
+ * Revision 1.12  2004/04/20 10:58:04  strk
+ * More memory leaks removed.
+ *
+ * Revision 1.11  2004/04/19 15:14:45  strk
+ * Added missing virtual destructor in SpatialIndex class.
+ * Memory leaks fixes. Const and throw specifications added.
+ *
+ * Revision 1.10  2004/04/19 12:51:01  strk
+ * Memory leaks fixes. Throw specifications added.
+ *
+ * Revision 1.9  2004/04/15 14:00:30  strk
+ * Added new cleanup to Unload::Release
+ *
+ * Revision 1.8  2004/04/10 08:40:01  ybychkov
+ * "operation/buffer" upgraded to JTS 1.4
+ *
+ * Revision 1.7  2004/03/01 22:04:59  strk
+ * applied const correctness changes by Manuel Prieto Villegas <ManuelPrietoVillegas@telefonica.net>
+ *
+ * Revision 1.6  2003/11/07 01:23:42  pramsey
+ * Add standard CVS headers licence notices and copyrights to all cpp and h
+ * files.
+ *
+ * Revision 1.5  2003/11/06 18:46:34  strk
+ * Added throw specification for BufferOp's ::buildSubgraphs() 
+ * and ::computeBuffer()
+ *
+ **********************************************************************/
+
