@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: IsValidOp.cpp,v 1.23 2004/09/13 12:50:11 strk Exp $
+ * $Id: IsValidOp.cpp,v 1.27 2004/12/08 13:54:44 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -11,52 +11,8 @@
  * by the Free Software Foundation. 
  * See the COPYING file for more information.
  *
- **********************************************************************
- * $Log: IsValidOp.cpp,v $
- * Revision 1.23  2004/09/13 12:50:11  strk
- * comments cleanup
- *
- * Revision 1.22  2004/09/13 12:39:14  strk
- * Made Point and MultiPoint subject to Validity tests.
- *
- * Revision 1.21  2004/09/13 10:12:49  strk
- * Added invalid coordinates checks in IsValidOp.
- * Cleanups.
- *
- * Revision 1.20  2004/09/13 09:18:10  strk
- * Added IsValidOp::isValid(Coordinate &)
- *
- * Revision 1.19  2004/07/08 19:34:50  strk
- * Mirrored JTS interface of CoordinateSequence, factory and
- * default implementations.
- * Added DefaultCoordinateSequenceFactory::instance() function.
- *
- * Revision 1.18  2004/07/02 13:28:29  strk
- * Fixed all #include lines to reflect headers layout change.
- * Added client application build tips in README.
- *
- * Revision 1.17  2004/05/18 00:02:37  ybychkov
- * IsValidOp::checkShellNotNested() bugfix from JTS 1.4.1 (not released yet) has been added.
- *
- * Revision 1.16  2004/03/29 06:59:25  ybychkov
- * "noding/snapround" package ported (JTS 1.4);
- * "operation", "operation/valid", "operation/relate" and "operation/overlay" upgraded to JTS 1.4;
- * "geom" partially upgraded.
- *
- * Revision 1.15  2003/11/07 01:23:42  pramsey
- * Add standard CVS headers licence notices and copyrights to all cpp and h
- * files.
- *
- * Revision 1.14  2003/10/15 11:24:28  strk
- * Use getCoordinatesRO() introduced.
- *
- * Revision 1.13  2003/10/13 17:54:40  strk
- * IsValidOp constructor used same name for the arg and a private 
- * element. Fixed.
- *
  **********************************************************************/
 
-
 #include <geos/opValid.h>
 #include <stdio.h>
 #include <typeinfo>
@@ -109,7 +65,9 @@ bool IsValidOp::isValid(const Coordinate &coord) {
 	return true;
 }
 
-TopologyValidationError* IsValidOp::getValidationError() {
+TopologyValidationError *
+IsValidOp::getValidationError()
+{
 	checkValid(parentGeometry);
 	return validErr;
 }
@@ -164,7 +122,7 @@ void IsValidOp::checkValid(const LinearRing *g){
 		return;
 	}
 	LineIntersector *li = new RobustLineIntersector();
-	graph->computeSelfNodes(li, true);
+	delete graph->computeSelfNodes(li, true);
 	checkNoSelfIntersectingRings(graph);
 	delete li;
 	delete graph;
@@ -177,35 +135,29 @@ void IsValidOp::checkValid(const LinearRing *g){
 void IsValidOp::checkValid(const Polygon *g){
 	checkInvalidCoordinates(g);
 	if (validErr != NULL) return;
-	GeometryGraph *graph=new GeometryGraph(0,g);
-	checkTooFewPoints(graph);
+	auto_ptr<GeometryGraph> graph(new GeometryGraph(0,g));
+	checkTooFewPoints(graph.get());
 	if (validErr!=NULL) {
-		delete graph;
 		return;
 	}
-	checkConsistentArea(graph);
+	checkConsistentArea(graph.get());
 	if (validErr!=NULL) {
-		delete graph;
 		return;
 	}
-	checkNoSelfIntersectingRings(graph);
+	checkNoSelfIntersectingRings(graph.get());
 	if (validErr!=NULL) {
-		delete graph;
 		return;
 	}
-	checkHolesInShell(g,graph);
+	checkHolesInShell(g,graph.get());
 	if (validErr!=NULL) {
-		delete graph;
 		return;
 	}
 	//SLOWcheckHolesNotNested(g);
-	checkHolesNotNested(g,graph);
+	checkHolesNotNested(g,graph.get());
 	if (validErr!=NULL) {
-		delete graph;
 		return;
 	}
-	checkConnectedInteriors(graph);
-	delete graph;
+	checkConnectedInteriors(graph.get());
 }
 
 void
@@ -353,7 +305,7 @@ void IsValidOp::checkNoRepeatedPoint(Geometry *g) {
 */
 void IsValidOp::checkHolesInShell(const Polygon *p,GeometryGraph *graph) {
 	LinearRing *shell=(LinearRing*) p->getExteriorRing();
-	const CoordinateSequence *shellPts=shell->getCoordinatesRO();
+	//const CoordinateSequence *shellPts=shell->getCoordinatesRO();
 	//PointInRing pir=new SimplePointInRing(shell);
 	//PointInRing pir=new SIRtreePointInRing(shell);
 //	auto_ptr<PointInRing> pir(new MCPointInRing(shell));
@@ -548,6 +500,66 @@ IsValidOp::checkInvalidCoordinates(const Polygon *poly)
 	}
 }
 
+} // namespace geos
 
-}
+/**********************************************************************
+ * $Log: IsValidOp.cpp,v $
+ * Revision 1.27  2004/12/08 13:54:44  strk
+ * gcc warnings checked and fixed, general cleanups.
+ *
+ * Revision 1.26  2004/11/06 08:16:46  strk
+ * Fixed CGAlgorithms::isCCW from JTS port.
+ * Code cleanup in IsValidOp.
+ *
+ * Revision 1.25  2004/11/05 11:41:57  strk
+ * Made IsValidOp handle IllegalArgumentException throw from GeometryGraph
+ * as a sign of invalidity (just for Polygon geometries).
+ * Removed leaks generated by this specific exception.
+ *
+ * Revision 1.24  2004/10/19 19:51:14  strk
+ * Fixed many leaks and bugs in Polygonizer.
+ * Output still bogus.
+ *
+ * Revision 1.23  2004/09/13 12:50:11  strk
+ * comments cleanup
+ *
+ * Revision 1.22  2004/09/13 12:39:14  strk
+ * Made Point and MultiPoint subject to Validity tests.
+ *
+ * Revision 1.21  2004/09/13 10:12:49  strk
+ * Added invalid coordinates checks in IsValidOp.
+ * Cleanups.
+ *
+ * Revision 1.20  2004/09/13 09:18:10  strk
+ * Added IsValidOp::isValid(Coordinate &)
+ *
+ * Revision 1.19  2004/07/08 19:34:50  strk
+ * Mirrored JTS interface of CoordinateSequence, factory and
+ * default implementations.
+ * Added DefaultCoordinateSequenceFactory::instance() function.
+ *
+ * Revision 1.18  2004/07/02 13:28:29  strk
+ * Fixed all #include lines to reflect headers layout change.
+ * Added client application build tips in README.
+ *
+ * Revision 1.17  2004/05/18 00:02:37  ybychkov
+ * IsValidOp::checkShellNotNested() bugfix from JTS 1.4.1 (not released yet) has been added.
+ *
+ * Revision 1.16  2004/03/29 06:59:25  ybychkov
+ * "noding/snapround" package ported (JTS 1.4);
+ * "operation", "operation/valid", "operation/relate" and "operation/overlay" upgraded to JTS 1.4;
+ * "geom" partially upgraded.
+ *
+ * Revision 1.15  2003/11/07 01:23:42  pramsey
+ * Add standard CVS headers licence notices and copyrights to all cpp and h
+ * files.
+ *
+ * Revision 1.14  2003/10/15 11:24:28  strk
+ * Use getCoordinatesRO() introduced.
+ *
+ * Revision 1.13  2003/10/13 17:54:40  strk
+ * IsValidOp constructor used same name for the arg and a private 
+ * element. Fixed.
+ *
+ **********************************************************************/
 
